@@ -1,6 +1,8 @@
-__version__ = "3.0.4"
+__version__ = "3.0.6"
 from janda.pururin import Pururin
 from janda.nhentai import Nhentai
 from janda.hentaifox import Hentaifox
 from janda.hentai2read import Hentai2read
+from janda.simply_hentai import SimplyHentai
+from janda.qhentai import Qhentai
 from janda.utils import *
\ No newline at end of file
