@@ -5,9 +5,21 @@ from .utils.parser import *
 BASE_URL = Api()
 
 class Hentaifox(object):
-    """
-    A class used to represent a doujin.
+    """ HentaiFox API wrapper 
+    
+    Methods
+    -------
+    get : function
+        Get doujin API from Id
 
+    search_by_latest : function
+        Search for doujin based on the latest
+
+    search_by_popular : function
+        Search for doujin based on the popular
+
+    get_random : function
+        Gets random doujin on hentaifox
     """
 
     def __init__(self, api_key: str = ''):
@@ -91,7 +103,7 @@ class Hentaifox(object):
 
         query = auto_space(query)
 
-        if query is '':
+        if query == '':
             raise ValueError('Query must be given')
         data = requests.get(BASE_URL.hentaifox + 'args.php', params=self.specs)
 
@@ -131,7 +143,7 @@ class Hentaifox(object):
 
         query = auto_space(query)
 
-        if query is '':
+        if query == '':
             raise ValueError('Query must be given')
         data = requests.get(BASE_URL.hentaifox + 'args.php', params=self.specs)
 
