@@ -5,24 +5,25 @@ from .utils.parser import *
 BASE_URL = Api()
 
 class Nhentai(object):    
+    """ Nhentai API wrapper 
+    
+    Methods
+    -------
+    get : function
+        Get doujin API from Id
 
-    def __init__(self, api_key: str = ''):
-        """Initializes the client.
+    search : function
+        Search doujin by tags / artist / character / parody or group
 
-        Parameters
-        ----------
-        api_key : str
-            scathach.dev API key for pururin (optional)
-        
-        Returns
-        -------
-        None
-        """
-        if api_key == '':
-            self.api_key = None
-        else:
-            self.api_key = api_key
-        self.specs = {'api_key': self.api_key}
+    search_related : function
+        Get related book API from book Id
+
+    get_random : function
+        Get random doujin
+    """
+
+    def __init__(self):
+        self.specs = {}
 
     async def get(self, book: int, safe: bool = None):
         """Get doujin API from Id
@@ -132,7 +133,7 @@ class Nhentai(object):
 
 
     async def search_related(self, book: int):
-        """Get realated book API from book ID or book link
+        """Get related book API from book ID or book link
 
         Parameters
         ----------
