@@ -5,10 +5,38 @@ from janda.utils.parser import *
 BASE_URL = Api()
 
 class Pururin(object):
-    """
-    A class used to represent a doujin.
+    """ Pururin API wrapper
+    
+    Methods
+    -------
+    get: function
+        Gets doujin from id
 
+    get_random: function
+        Gets random doujin
+
+    get_random_with_query: function
+        Gets random doujin with query
+
+    search_by_newest: function
+        Searches for doujin based on newest
+
+    search_by_most_popular: function
+        Searches doujin based on most popular
+
+    search_by_highest_rated: function
+        Searches doujin based on highest rated
+
+    search_by_most_viewed: function
+        Searches doujin based on most viewed
+
+    search_by_title: function
+        Searches doujin based on title
+
+    search_by_random: function
+        Searches doujin based on random with query
     """
+
     @staticmethod
     def better_object(parser: dict):
         """Converts the json object to a more readable object.
@@ -39,8 +67,12 @@ class Pururin(object):
         ----------
         api_key : str
             scathach.dev API key (optional)
+
+        Attributes
+        ----------
+        get: 
         """
-        if api_key is '':
+        if api_key == '':
             self.api_key = None
         else:
             self.api_key = api_key
@@ -108,7 +140,7 @@ class Pururin(object):
         self.specs['sort'] = "newest"
         query = Pururin.auto_space(query)
 
-        if query is '':
+        if query == '':
             raise ValueError('Query must be given')
         data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)
 
@@ -143,7 +175,7 @@ class Pururin(object):
         self.specs['sort'] = "most-popular"
         query = Pururin.auto_space(query)
 
-        if query is '':
+        if query == '':
             raise ValueError('Query must be given')
         data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)
 
@@ -178,7 +210,7 @@ class Pururin(object):
         self.specs['sort'] = "highest-rated"
         query = Pururin.auto_space(query)
 
-        if query is '':
+        if query == '':
             raise ValueError('Query must be given')
         data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)
 
@@ -213,7 +245,7 @@ class Pururin(object):
         self.specs['sort'] = "most-viewed"
         query = Pururin.auto_space(query)
 
-        if query is '':
+        if query == '':
             raise ValueError('Query must be given')
         data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)
 
@@ -248,7 +280,7 @@ class Pururin(object):
         self.specs['sort'] = "title"
         query = Pururin.auto_space(query)
 
-        if query is '':
+        if query == '':
             raise ValueError('Query must be given')
         data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)
 
@@ -283,7 +315,7 @@ class Pururin(object):
         self.specs['sort'] = "random"
         query = Pururin.auto_space(query)
 
-        if query is '':
+        if query == '':
             raise ValueError('Query must be given')
         data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)
 
@@ -335,3 +367,4 @@ class Pururin(object):
             raise ValueError('No results found')
 
         return Pururin.better_object(data.json())
+
